## Steps for contributing ##
1. Do a fork of the repository.
2. Clone your fork in it create a branch and there do your changes.
3. Commit your changes.
   Rules for commits:
   * Write the message with imperative mode.
   * Be descriptive but concise with your commits msg (you can add a description and footer if you want).
   * Reference to the issue that you worked on with [#issue] at the start of your last commit.
   * First letter of commits msg always in upper case.
4. Push your changes to your fork.
5. Then create a PR comparing this repository with your fork.
